# Makefile for AUCTeX

# Maintainer: auctex-devel@gnu.org

# Copyright (C) 2003-2008, 2010, 2013, 2014 Free Software
#   Foundation, Inc.

# This file is part of AUCTeX.

# AUCTeX is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# AUCTeX is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with AUCTeX; see the file COPYING.  If not, write to the Free
# Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301, USA.



prefix = /usr/local$(null)
exec_prefix = ${prefix}$(null)
libdir = ${exec_prefix}/lib$(null)
packagedatadir = ${datadir}/emacs/site-lisp/auctex$(null)
datarootdir = ${prefix}/share$(null)
datadir = ${datarootdir}$(null)
localstatedir = ${prefix}/var$(null)
infodir = ${datarootdir}/info$(null)
lispdir = ${datadir}/emacs/site-lisp$(null)
auctexstartfile=${datadir}/emacs/site-lisp/auctex.el
packagelispdir = ${datadir}/emacs/site-lisp/auctex$(null)
packagedatadir = ${datadir}/emacs/site-lisp/auctex$(null)
packagedir = no$(null)
autodir = ${localstatedir}/auctex$(null)
preview_enabled=yes
subdirs= preview
styledir = $(packagedatadir)/style
AUCTEXDATE = 2014-10-29
AUCTEXVERSION = 11.88

INSTALL = /usr/bin/install -c
INSTALL_DATA = ${INSTALL} -m 644
MKINSTALLDIRS = ./mkinstalldirs
DESTDIR=

PACKAGE=auctex
PACKAGE_INFO=auctex preview-latex
EMACS=/usr/bin/emacs
ELCC=$(EMACS) -batch -q -no-site-file -no-init-file -l lpath.el
AUTOLOAD=--eval '(let ((generated-autoload-file (expand-file-name "$@"))) \
  (mapcar (function update-file-autoloads) command-line-args-left) \
  (save-buffers-kill-emacs t))'
DESCEND=test -z "$(subdirs)" || (OLDPWD="`pwd`";for i in ""$(subdirs);do cd $$i;echo "Descending into `pwd`";$(MAKE) 'DESTDIR=$(DESTDIR)' PACKAGE=$(PACKAGE) $@ || exit $$?;cd "$$OLDPWD";echo "Ascending into $$OLDPWD";done)

EXCLUDEDFILES=autogen.sh .cvsignore .gitignore doc/.gitignore preview/.gitignore \
	preview/latex/.gitignore README.GIT tests

.SUFFIXES: .el .elc .texi

SHELL = /bin/sh
CP = cp -p
CP_A = $(CP) -R

DIST_PREFIX=$(PWD)/auctex-dist
FTPDIR = $(DIST_PREFIX)/ftp
WWWDIR = $(DIST_PREFIX)/www
XEMACS_BUILD_DIR = xemacs-build
PREVIEW_BUILD_DIR = preview-build
COMMITTER="`git config --get user.name`\ \ \<`git config --get user.email`\>"
RPMROOT = /usr/src/redhat
RPM_SIGN = --sign

MULESRC = tex-jp.el
MULEELC = tex-jp.elc

AUCSRC = tex.el tex-buf.el tex-style.el plain-tex.el latex.el tex-info.el \
	texmathp.el multi-prompt.el tex-mik.el font-latex.el tex-font.el \
	context.el context-en.el context-nl.el tex-fold.el \
	toolbar-x.el tex-bar.el bib-cite.el
AUCELC = $(AUCSRC:.el=.elc)

STYLESRC = style/prosper.el \
	   style/slides.el    style/foils.el     style/amstex.el \
	   style/article.el   style/book.el      style/letter.el \
	   style/report.el    style/amsart.el    style/amsbook.el \
	   style/epsf.el      style/psfig.el     style/latexinfo.el \
	   style/dutch.el     style/german.el    style/dk.el \
	   style/j-article.el style/j-book.el    style/j-report.el \
	   style/jarticle.el  style/jbook.el     style/jreport.el \
	   style/dinbrief.el  style/virtex.el    style/plfonts.el \
	   style/plhb.el      style/harvard.el	 style/swedish.el \
	   style/danish.el    style/slovak.el    style/czech.el \
	   style/amsmath.el   style/amstext.el   style/amsbsy.el \
	   style/amsopn.el    style/amsthm.el	 style/natbib.el \
	   style/index.el     style/makeidx.el   style/multind.el \
	   style/varioref.el  style/fancyref.el	 style/mdwlist.el \
	   style/ngerman.el   style/graphicx.el	 style/graphics.el \
	   style/verbatim.el  style/scrbase.el   style/scrartcl.el \
	   style/scrbook.el   style/scrreprt.el	 style/scrlttr2.el \
	   style/scrpage2.el  style/captcont.el  style/subfigure.el \
	   style/paralist.el  style/booktabs.el  style/emp.el \
	   style/jura.el      style/alphanum.el	 style/beamer.el \
	   style/alltt.el     style/italian.el   style/doc.el \
	   style/ltxdoc.el    style/ltx-base.el	 style/units.el \
	   style/nicefrac.el  style/url.el       style/listings.el \
	   style/jurabib.el   style/csquotes.el  style/jsarticle.el \
	   style/jsbook.el    style/babel.el     style/dk-bib.el \
	   style/inputenc.el  style/frenchb.el   style/francais.el \
	   style/MinionPro.el style/pdfsync.el   style/polish.el \
	   style/polski.el    style/icelandic.el style/comment.el \
	   style/flashcards.el style/pstricks.el style/nomencl.el \
	   style/hyperref.el  style/bulgarian.el style/CJK.el \
	   style/ruby.el      style/CJKutf8.el   style/tabularx.el \
	   style/multido.el   style/pst-grad.el  style/pst-node.el \
	   style/pst-plot.el  style/pst-slpe.el  style/shortvrb.el \
	   style/austrian.el  style/naustrian.el style/french.el \
	   style/lettrine.el  style/multicol.el  style/xspace.el \
	   style/setspace.el  style/biblatex.el  style/siunitx.el \
	   style/bm.el        style/footmisc.el  style/ulem.el \
	   style/bigdelim.el  style/bigstrut.el  style/everysel.el \
	   style/mathtools.el style/ragged2e.el  style/amssymb.el \
	   style/lscape.el    style/epigraph.el  style/mflogo.el \
	   style/multirow.el  style/imakeidx.el  style/afterpage.el \
	   style/longtable.el style/lipsum.el    style/kantlipsum.el \
	   style/memoir.el    style/placeins.el  style/nameref.el \
	   style/fancynum.el  style/fancyhdr.el	 style/filecontents.el \
	   style/array.el     style/kpfonts.el   style/acro.el \
	   style/acronym.el   style/xparse.el    style/fancyvrb.el \
	   style/tabulary.el  style/fontspec.el  style/unicode-math.el \
	   style/luacode.el   style/metalogo.el  style/english.el \
	   style/exercise.el  style/plext.el     style/cleveref.el
STYLEELC = $(STYLESRC:.el=.elc)

CLEANFILES = $(AUCELC) $(STYLEELC) $(MULEELC)
DISTCLEANFILES = Makefile tex-site.el tex-site.el.out auctex.el \
	auto-loads.el config.* preview/preview.el
DISTTEXTS = FAQ INSTALL INSTALL.windows README TODO PROBLEMS.preview

NOSEARCH = style/.nosearch

all: lisp docs
	$(DESCEND)

.PHONY: all lisp info dvi some install install-el install-lisp docs	\
	install-docs install-auto install-metadata install-startup	\
	install-man clean distclean maintainer-clean extraclean		\
	tar-ball-clean check-tag release-commit dist snapshot patch	\
	tar-ball rpm-packages wc xemacs-package windows-package		\
	release-sign release-upload preview-ball

lisp:	tex-site.el $(AUCSRC) $(STYLESRC) $(MULESRC)
	$(ELCC) -f batch-byte-compile $(AUCSRC) $(STYLESRC) $(MULESRC)

docs:
	cd doc ; $(MAKE) all

info:
	cd doc ; $(MAKE) info

dvi:
	cd doc ; $(MAKE) dvi

tex-site.el: tex-site.el.out auto-loads.el Makefile
	cat tex-site.el.out >$@
	test X$(packagedir) != Xno || cat auto-loads.el >>$@
	echo "(provide 'tex-site)" >>$@ ; \
	test X$(packagedir) != Xno || echo ";;; tex-site.el ends here" >>$@

tex-site.el.out: tex-site.el.in Makefile config.status
	./config.status

auctex.el: auctex.el.in config.status
	./config.status

configure: configure.ac aclocal.m4
	autoconf

Makefile: Makefile.in config.status
	./config.status

doc/Makefile: doc/Makefile.in config.status ChangeLog
	./config.status

config.status: configure
	./config.status --recheck

auto-loads.el: $(AUCSRC) $(MULESRC) Makefile
	test X$(packagedir) != Xno || { \
	  rm -f $@ ; \
	  $(ELCC) $(AUTOLOAD) $(AUCSRC) $(MULESRC) || : ; \
	  test -r $@ || { \
	    echo ";; Auto-generated part of tex-site.el" > $@ ; \
	    echo "" >> $@ ; \
	    $(ELCC) $(AUTOLOAD) $(AUCSRC) $(MULESRC) ; \
	  } ; \
	}

some:	$(AUCELC) $(STYLEELC)

install: install-lisp install-docs install-images install-startup
	$(DESCEND)
	$(MAKE) 'DESTDIR=$(DESTDIR)' install-metadata

install-man: doc/Makefile
	cd doc && $(MAKE) 'DESTDIR=$(DESTDIR)' install-man
	$(INSTALL_DATA) RELEASE $(DESTDIR)$(packagedir)/man/auctex

install-startup:
	test $(packagedir) != no || \
	  $(INSTALL_DATA) auctex.el $(DESTDIR)$(auctexstartfile)

install-el:
	-$(MKINSTALLDIRS) $(DESTDIR)$(lispdir)
	rm -f $(DESTDIR)$(packagelispdir)/tex-site.el # Remove old (Git-version) mistakes
	test ! -f $(DESTDIR)$(lispdir)/tex-site.el || { \
	   if grep -q "tex-site.*Don't edit." $(DESTDIR)$(lispdir)/tex-site.el; then \
	    echo "Overwriting old tex-site.el" ; \
	   else \
	    echo "Renaming old tex-site.el to tex-site.el.save" ; \
	    mv $(DESTDIR)$(lispdir)/tex-site.el $(DESTDIR)$(lispdir)/tex-site.el.save ; \
	   fi; \
	}
	if test X$(packagedir) = Xno; \
	then $(INSTALL_DATA) tex-site.el $(DESTDIR)$(lispdir) ; \
	else rm -f $(DESTDIR)$(lispdir)/tex-site.el ; \
	fi
	-$(MKINSTALLDIRS) $(DESTDIR)$(packagelispdir)
	@: $(MAKE) ; for x in $(AUCSRC) $(MULESRC); do \
	  echo '$(INSTALL_DATA)' $$x '$(DESTDIR)$(packagelispdir)' ; \
	done
	@for x in $(AUCSRC) $(MULESRC); do \
	  $(INSTALL_DATA) $$x $(DESTDIR)$(packagelispdir) ; \
	done;
	-$(MKINSTALLDIRS) $(DESTDIR)$(styledir)
	$(INSTALL_DATA) $(NOSEARCH) $(DESTDIR)$(styledir)
	@: $(MAKE) ; for x in $(STYLESRC) ; do \
	  echo '$(INSTALL_DATA)' $$x '$(DESTDIR)$(styledir)' ; \
	done;
	@for x in $(STYLESRC) ; do \
	  $(INSTALL_DATA) $$x $(DESTDIR)$(styledir) ; \
	done;
	-$(MKINSTALLDIRS) $(DESTDIR)$(autodir)
	-$(INSTALL_DATA) $(NOSEARCH) $(DESTDIR)$(autodir)

install-lisp: some install-el
	@: $(MAKE) ; for x in $(AUCSRC) $(MULESRC); do \
	  echo '$(INSTALL_DATA)' $${x}c '$(DESTDIR)$(packagelispdir)' ; \
	done
	@for x in $(AUCSRC) $(MULESRC); do \
	  $(INSTALL_DATA) $${x}c $(DESTDIR)$(packagelispdir) ; \
	done
	@: $(MAKE) ; for x in $(STYLESRC) ; do \
	  echo '$(INSTALL_DATA)' $${x}c '$(DESTDIR)$(styledir)' ; \
	done
	@for x in $(STYLESRC) ; do \
	  $(INSTALL_DATA) $${x}c $(DESTDIR)$(styledir) ; \
	done

install-images:
	-$(MKINSTALLDIRS) $(DESTDIR)$(packagedatadir)/images
	@: $(MAKE) ; for x in images/*.xpm ; do \
	  echo '$(INSTALL_DATA)' $${x} '$(DESTDIR)$(packagedatadir)/images' ; \
	done
	@for x in images/*.xpm ; do \
	  $(INSTALL_DATA) $${x} $(DESTDIR)$(packagedatadir)/images ; \
	done

install-docs:	doc/Makefile
	cd doc ; $(MAKE) DESTDIR=$(DESTDIR) install-auctex
	test "x$(preview_enabled)" != xyes || { \
		cd doc ; $(MAKE) DESTDIR=$(DESTDIR) install-preview; }

install-auto:
	@echo "Use \"M-x TeX-auto-generate-global RET\" instead."

install-metadata:
	test "x$(packagedir)" = xno || { \
	  $(MKINSTALLDIRS) $(DESTDIR)$(packagedir)/pkginfo || : ; \
	  if test "x$(preview_enabled)" = xyes; then \
	    $(ELCC) -l preview/prv-install -f preview-make-package $(DESTDIR)$(packagedir) "$(PACKAGE)" \"`echo $(AUCTEXDATE)|sed 's/\(.*\)-\(.*\)-\(.*\)/\1.\2\3/'`\" \"$(AUCTEXVERSION)\" tex-site.el preview/auto.el; \
	  else \
	    $(ELCC) -l preview/prv-install -f preview-make-package $(DESTDIR)$(packagedir) "$(PACKAGE)" \"`echo $(AUCTEXDATE)|sed 's/\(.*\)-\(.*\)-\(.*\)/\1.\2\3/'`\" \"$(AUCTEXVERSION)\" tex-site.el; \
	  fi && \
	  cd $(DESTDIR)$(packagedir) && \
	  find "etc/$(PACKAGE)" "lisp/$(PACKAGE)" -print >"pkginfo/MANIFEST.$(PACKAGE)" && \
	  for i in $(PACKAGE_INFO); do \
	    test -r "info/$$i.info" && echo "info/$$i.info" >> "pkginfo/MANIFEST.$(PACKAGE)" ; \
	  done && \
	  echo "pkginfo/MANIFEST.$(PACKAGE)" >> "pkginfo/MANIFEST.$(PACKAGE)" ; \
	}

.el.elc:
	$(ELCC) -f batch-byte-compile $<

clean:	doc/Makefile
	rm -f $(CLEANFILES)
	cd doc && $(MAKE) clean
	$(DESCEND)

distclean: doc/Makefile
	rm -f $(CLEANFILES) $(DISTCLEANFILES)
	cd doc && $(MAKE) distclean
	$(DESCEND)

maintainer-clean: doc/Makefile
	rm -f $(DISTTEXTS)
	rm -rf autom4te.cache
	rm -f $(CLEANFILES) $(DISTCLEANFILES)
	cd doc && $(MAKE) maintainer-clean
	$(DESCEND)

extraclean: maintainer-clean
	rm -f *~ \#*\#

tar-ball-clean: check-tag
	rm -rf auctex-$(TAG)/
	rm -rf $(XEMACS_BUILD_DIR)/

wc:
	wc $(AUCSRC) $(STYLESRC)

# ----------------------------------------------------------------------
# The targets below are concerned with the release process and
# intended to be used only by the maintainers.

# Steps for making a release:
#
# 1) release-commit TAG=<tag> COMMITTER=<committer>
#    Tag the release.
#    Pass `COMMITTER=<committer>' argument only if it is different from
#    your git name and email.  `<committer>' should be in the form
#        "John Doe  <john.doe@example.com>"
#
# 2) dist TAG=<tag>
#    Create the tar ball and other release files and put them into $FTPDIR.
#
# 3) xemacs-package TAG=<tag>
#    Create the precompiled XEmacs package.
#
# 4) windows-package WEMACSVER=<emacs-version> TAG=<tag>
#    Create the precompiled AUCTeX package for Windows.
#    This requires a compiled Emacs of the same version at location $WEMACS.
#
# 5) release-sign TAG=<tag>
#    Sign the tar ball and create directive files for upload.
#
# 6) release-upload
#    Upload files to GNU FTP server.
#
# 7) www-doc TAG=<tag> GENDOCSPATCH=<patch-file>
#    Create documentation for AUCTeX home page.
#
# 8) preview-ball TAG=<tag>
#    Create preview package.  (Not for GNU FTP server but for CTAN.)

dist: check-tag tar-ball

snapshot: dist

check-tag:
	@if [ "X$(TAG)" = "X" ]; then echo "*** Error: No TAG ***"; exit 1; fi

release-commit: check-tag
	@echo "Tagging release $(TAG) in Git ..."
	sleep 5
	mv ChangeLog ChangeLog.old
	mv preview/ChangeLog preview/ChangeLog.old
# Make sure the release ChangeLog entry is encoded with ISO-8859-1.  This
# requires the `iconv' program.
	echo `date "+%Y-%m-%d "`" ${COMMITTER}" | iconv -t ISO-8859-1 - > ChangeLog
	echo >> ChangeLog
	echo "	* Version" $(TAG) released. >> ChangeLog
	echo >> ChangeLog
	cp ChangeLog preview/ChangeLog
	cat ChangeLog.old >> ChangeLog
	cat preview/ChangeLog.old >> preview/ChangeLog
	git commit -m 'Release_$(TAG)' -- ChangeLog preview/ChangeLog
	git tag release_`echo $(TAG) | sed -e 's/[.]/_/g'`
	@echo
	@echo "Congratulations!  Release $(TAG) of AUCTeX is ready."
	@echo "Please, remember to run"
	@echo "    git push --tags origin master"
	@echo "to propagate release commit and tag to the remote repository."

tar-ball: doc/Makefile
	test ! -d auctex-$(TAG) || rm -r auctex-$(TAG)
	mkdir auctex-$(TAG)
# Use TAG_EXPORT if set (for snapshots)
	git archive $${TAG_EXPORT:=`echo release_$(TAG) | sed 's/[.]/_/g'`} | tar -xC auctex-$(TAG)
	cd auctex-$(TAG) && AUCTEXVERSION=$(TAG) AUCTEXDATE=$(AUCTEXDATE) ./autogen.sh && rm -rf $(EXCLUDEDFILES)
	chmod -R go-w+rX auctex-$(TAG)
	rm -rf $(FTPDIR)
	mkdir -p $(FTPDIR)
	tar -cf - --owner=root --group=root auctex-$(TAG) | gzip --best > $(FTPDIR)/auctex-$(TAG).tar.gz
	-zip -r $(FTPDIR)/auctex-$(TAG).zip auctex-$(TAG)
	$(CP) auctex-$(TAG)/CHANGES $(FTPDIR)/CHANGES
	$(CP) auctex-$(TAG)/RELEASE $(FTPDIR)/RELEASE-$(TAG)
# The following files aren't produced in auctex-$(TAG) since they
# are not in the tarball and should not become part of the patch target.
	$(CP) auctex-$(TAG)/doc/version.texi doc/version.texi
	cd doc && $(MAKE) extradist
	rm -f doc/version.texi
	$(CP) doc/auctex.ps doc/auctex.pdf doc/tex-ref.ps doc/tex-ref.pdf $(FTPDIR)
	$(CP) ChangeLog $(FTPDIR)

rpm-packages:
	rpmbuild -ta $(RPM_SIGN) $(FTPDIR)/auctex-$(TAG).tar.gz
	$(CP) $(RPMROOT)/{RPMS/noarch/{auctex-emacs,preview-tetex},SRPMS/auctex}-$(TAG)[.-]* $(FTPDIR)
	@echo "If you need to prepare RPM on some other system, you need to add"
	@echo "them in $(FTPDIR) before 'make release-sign'."
	sleep 2

patch:
	diff -u auctex-$(OLD) auctex-$(TAG) | gzip --best \
		>$(FTPDIR)/auctex-$(OLD)-to-$(TAG).patch.gz

xemacs-package: check-tag
	rm -rf $(XEMACS_BUILD_DIR)
	$(CP_A) auctex-$(TAG) $(XEMACS_BUILD_DIR)
	cd $(XEMACS_BUILD_DIR) \
	&& ./configure INSTALL_INFO=: TEXHASH=: --with-xemacs --with-packagedir=`pwd`/xemacs-package --without-texmf-dir --with-auto-dir=etc/auctex/auto \
	&& make all install-man install && cd xemacs-package && tar -cf - --owner=root --group=root . | gzip --best > $(FTPDIR)/auctex-$(TAG)-pkg.tar.gz

# Pre-compiled AUCTeX package for Emacs on Windows
WBUILDDIR=$(PWD)/windows-package
WEMACS=/usr/src/emacs-$(WEMACSVER)/src/emacs
WPACKAGE=auctex-$(TAG)-e$(WEMACSVER)-msw.zip
WPACKAGEFILES=site-lisp/auctex site-lisp/site-start.d site-lisp/site-start.el \
	site-lisp/tex-site.el var/auctex doc info/dir info/auctex.info* \
	info/preview-latex.info*
windows-package: check-tag
	@if [ "X$(WEMACSVER)" = "X" ]; then \
	  echo "*** Error: No Emacs version (WEMACSVER) ***"; \
	  exit 1; \
	fi
# Make sure the prerequisites are available
	test -d $(WBUILDDIR) || mkdir $(WBUILDDIR)
	test -f $(WBUILDDIR)/emacs-$(WEMACSVER)-bin-i386.zip \
	|| { cd $(WBUILDDIR) \
	&& wget http://ftp.gnu.org/gnu/emacs/windows/emacs-$(WEMACSVER)-bin-i386.zip; }
	test -f $(WBUILDDIR)/auctex-$(TAG).zip \
	|| { test -f $(FTPDIR)/auctex-$(TAG).zip \
	  && $(CP) $(FTPDIR)/auctex-$(TAG).zip $(WBUILDDIR); } \
	|| { cd $(WBUILDDIR) \
	  && wget http://ftp.gnu.org/gnu/auctex/auctex-$(TAG).zip; }
# Reset to clean state
	cd $(WBUILDDIR) \
	&& rm -rf emacs-$(WEMACSVER) \
	&& rm -rf auctex-$(TAG) \
	&& unzip emacs-$(WEMACSVER)-bin-i386.zip \
	&& unzip auctex-$(TAG).zip
	rm -f $(WPACKAGE)
# Create site-start.el and site-start.d
	cd $(WBUILDDIR)/emacs-$(WEMACSVER)/site-lisp \
	&& echo -e ";; Load files in \`site-start.d' directory.\
\n(dolist (file (directory-files\
\n	       (concat (file-name-directory load-file-name) \"site-start.d\")\
\n	       t \"\\\\\\\\.el\\\\\\\\'\"))\
\n  (load file nil t t))" > site-start.el \
	&& mkdir site-start.d
# Build and install AUCTeX
	cd $(WBUILDDIR)/auctex-$(TAG) \
	&& ./configure --prefix=$(WBUILDDIR)/emacs-$(WEMACSVER) \
	  --without-texmf-dir --with-emacs=$(WEMACS) \
	  --with-lispdir=$(WBUILDDIR)/emacs-$(WEMACSVER)/site-lisp \
	  --datarootdir=$(WBUILDDIR)/emacs-$(WEMACSVER) \
	&& make \
	&& sed -i -e 's/"\/[^\n]\+/(expand-file-name "..\/var\/auctex" (file-name-directory load-file-name))/' tex-site.el \
	&& make install
# Create the package
	test -d $(FTPDIR) || mkdir -p $(FTPDIR)
	cd $(WBUILDDIR)/emacs-$(WEMACSVER) \
	&& zip -r $(FTPDIR)/$(WPACKAGE) $(WPACKAGEFILES)

release-sign: check-tag
	rm -f $(FTPDIR)/*.{directive,asc,sig}
	if [ "x$$GPG_AGENT_INFO" = "x" ]; then \
	  read -sp "Enter pass phrase: " phrase ; \
	  gpg_opt="--passphrase-fd 0"; \
	else \
	  gpg_opt=""; phrase=""; \
	fi; \
	for i in $(FTPDIR)/*; do \
	   echo "$$phrase" | gpg --detach-sign $$gpg_opt $$i ; \
	   echo "version: 1.1" >$$i.directive; \
	   case $$i in *-$(TAG)*) echo "directory: auctex" >>$$i.directive;; \
	      *) echo "directory: auctex/$(TAG)-extra" >>$$i.directive ;; \
	   esac ; \
	   echo "filename: "`basename $$i` >>$$i.directive ; \
	   echo "$$phrase" | gpg $$gpg_opt --clearsign $$i.directive ; \
	done
	rm $(FTPDIR)/*.directive

release-upload:
	@echo "Uploading everything in FTPDIR to GNU FTP server ..."
	@sleep 5
	ncftpput ftp-upload.gnu.org /incoming/ftp $(FTPDIR)/*

# AUCTeX and preview-latex manuals for the home page
www-doc: check-tag
	rm -rf $(WWWDIR)
	mkdir -p $(WWWDIR)/manual
	$(CP) auctex-$(TAG)/doc/*.texi $(WWWDIR)/manual
	cd $(WWWDIR)/manual \
	&& wget -O gendocs.sh 'http://cvs.savannah.gnu.org/viewvc/%2acheckout%2a/texinfo/texinfo/util/gendocs.sh' \
	&& patch <$(GENDOCSPATCH) \
	&& chmod u+x gendocs.sh \
	&& wget -O gendocs_template 'http://cvs.savannah.gnu.org/viewvc/%2acheckout%2a/texinfo/texinfo/util/gendocs_template' \
	&& sed -i -e 's/html_node\/index\.html/%%PACKAGE%%\/index.html/' gendocs_template \
	&& mkdir .texinfo \
	&& echo -e "emacs split http://www.gnu.org/software/emacs/manual/html_node/emacs/\nemacs mono http://www.gnu.org/software/emacs/manual/html_mono/emacs.html\nreftex split http://www.gnu.org/software/auctex/manual/reftex/\nreftex mono http://www.gnu.org/software/auctex/manual/reftex.html\n" > .texinfo/htmlxref.cnf \
	&& ./gendocs.sh --email bug-auctex@gnu.org --texi2html \
	  --html --use-nodes auctex "AUCTeX Manual" \
	&& ./gendocs.sh --email bug-auctex@gnu.org --texi2html \
	  --html --use-nodes preview-latex "preview-latex Manual"

preview-ball: check-tag
	test ! -d $(PREVIEW_BUILD_DIR) || rm -r $(PREVIEW_BUILD_DIR)
	mkdir $(PREVIEW_BUILD_DIR)
# Use TAG_EXPORT if set (for snapshots)
	git archive $${TAG_EXPORT:=`echo release_$(TAG) | sed 's/[.]/_/g'`} \
	  preview/latex | tar -xC $(PREVIEW_BUILD_DIR) --strip-components=2
	cd $(PREVIEW_BUILD_DIR) && make -f ../preview/latex/Makefile preview.ins preview.pdf
	chmod -R go-w+rX $(PREVIEW_BUILD_DIR)
	test -d $(FTPDIR) || mkdir -p $(FTPDIR)
	cd $(PREVIEW_BUILD_DIR) && \
	tar -cf - --owner=root --group=root README preview.dtx preview.ins preview.pdf | gzip --best > $(FTPDIR)/preview-$(TAG).tar.gz
