#
#   Copyright 2009-2013 Free Software Foundation, Inc.
#
#  This	program	is free	software: you can redistribute it and/or modify
#  it under the	terms of the GNU General Public	License	as published by
#  the Free Software Foundation, either	version	3 of the License, or
#  (at your option) any	later version.
#
#  This	program	is distributed in the hope that	it will	be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
#  GNU General Public License for more details.
#
#   You	should have received a copy of the GNU General Public License
#  along with this program.  If	not, see <http://www.gnu.org/licenses/>.
#
# ----------------------------------------------------------------------
#		Makefile for main library
#-----------------------------------------------------------------------
#
SHELL		=	/bin/sh

prefix		=	/usr/local
exec_prefix	=	${prefix}
AR		=	ar
CC		=	libtool	--mode=compile gcc
PARENT		=	..
BASE		=	../..
HDRS		=	$(PARENT)/hdrs
CCFLAGS		=	-O -g -Wall -fno-stack-protector	
CFLAGS		=	$(CCFLAGS) -I$(HDRS) -I$(BASE)  -I/usr/include/libxml2
LIBDIR		=	$(DESTDIR)${exec_prefix}/lib
RPATH		=	${exec_prefix}/lib
LDSHARED	=	ld -shared -o
LIB		=	libgnubatch_int.la
LIBCLIENT	=	libgnubatch_client.la
LIBCURS		=	libgnubatch_curs.la
RM		=	rm -f
INSTALL		=	/usr/bin/install -c
INSTALL_DATA	=	${INSTALL} -m 644

OBJECTS=altlen.o	condname.o	getbtuser.o	getscript.o \
	op_icf.o	runpwd.o	spath.o		stringsch.o \
	helprdalt.o 	net_feed.o	mkspid.o	helpprmpt.o \
	open_ci.o 	envgetserv.o	advtime.o	disp_alt.o \
	packjstring.o 	qmatch.o	mpermitted.o	calchash.o \
	disperror.o 	helpvec.o	mmangle.o	help_readl.o \
	helprdn.o 	prin_gname.o	look_host.o	ncstrncmp.o \
	prin_uname.o 	getpwgrpents.o	envprocess.o	strread.o \
	stracpy.o	versionprint.o

# libgnubatch_client is	for client programs

CLIENTOBJS=\
	cgifndjb.o	cgiuser.o	cgiutil.o	chkfuture.o \
	dumpargs.o	dumpconds.o	dumpecrun.o	dumpemode.o \
	dumpmode.o	dumpnstr.o	dumpredirs.o	dumptime.o \
	getxbuf.o	gprompt.o	helpnstate.o	lookup_alt.o \
	open_cfile.o	optdisp.o	optkeyword.o	optpparm.o \
	optprocess.o	opttime.o	optvars.o	produser.o \
	readreply.o	remsubops.o	repmnthfix.o	shutilmsg.o \
	spit_cond.o	spit_msg.o	spit_pparm.o	spit_redir.o \
	spit_time.o	xmlinit.o	xmlload.o	xmlsave.o \
	rjfile.o	htmllib.o	spitbtrstr.o 	stringvec.o \
	makeovec.o	helpargs.o	doenv.o 	rdoptfile.o \
	dumpcon.o	saveopts.o	rvfile.o	makevec.o \
	doopts.o	dumpstr.o

# libgnubatch_curs is for clients which	use curses routines

CURSOBJS=\
	galts.o		helphdr.o	setkey.o	wgets.o \
	whdrstr.o	whexnum.o	wnum.o		make_km.o \
	getkey.o

LIBOBJECTS=$(OBJECTS:.o=.lo)
LIBCLIENTOBJS=$(CLIENTOBJS:.o=.lo)
LIBCURSOBJS=$(CURSOBJS:.o=.lo)

all:	$(OBJECTS) $(CLIENTOBJS) $(CURSOBJS)
	libtool	--mode=link gcc $(CCFLAGS) -o $(LIB) $(LIBOBJECTS) -rpath $(RPATH) -version-info 1:0:0
	libtool	--mode=link gcc $(CCFLAGS) -o $(LIBCLIENT) $(LIBCLIENTOBJS) -lxml2 -rpath $(RPATH) -version-info 1:0:0
	libtool	--mode=link gcc $(CCFLAGS) -o $(LIBCURS) $(LIBCURSOBJS) -rpath	$(RPATH) -version-info 1:0:0

install: all
	$(INSTALL) -d -m 755 $(LIBDIR)
	libtool	--mode=install $(INSTALL) $(LIB) $(LIBDIR)
	libtool	--mode=install $(INSTALL) $(LIBCLIENT) $(LIBDIR)
	libtool	--mode=install $(INSTALL) $(LIBCURS) $(LIBDIR)
	$(RM) $(LIBDIR)/libgnubatch_int.a $(LIBDIR)/libgnubatch_client.a $(LIBDIR)/libgnubatch_curs.a
	$(INSTALL_DATA)	$(LIB) $(LIBCLIENT) $(LIBCURS) $(LIBDIR)

install_strip:
	$(INSTALL) -d -m 755 $(LIBDIR)
	libtool	--mode=install $(INSTALL) -s $(LIB) $(LIBDIR)
	libtool	--mode=install $(INSTALL) -s $(LIBCLIENT) $(LIBDIR)
	libtool	--mode=install $(INSTALL) -s $(LIBCURS)	$(LIBDIR)
	$(RM) $(LIBDIR)/libgnubatch_int.a $(LIBDIR)/libgnubatch_client.a $(LIBDIR)/libgnubatch_curs.a
	$(INSTALL_DATA)	$(LIB) $(LIBCLIENT) $(LIBCURS) $(LIBDIR)

clean:
	$(RM) *.[oa] *.so *.la *.lo
	$(RM) -r .libs

distclean:	clean
	$(RM) Makefile
