# Makefile.sub for `chem'

# File position: <groff-source>/contrib/chem/Makefile.sub

# Copyright (C) 2006-2014  Free Software Foundation, Inc.
# Written by Bernd Warken <groff-bernd.warken-72@web.de>.

# This file is part of `chem' which is part of `groff'.

# `groff' is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License (GPL) version 2 as
# published by the Free Software Foundation.

# `groff' is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# The GPL2 license text is available in the internet at
# <http://www.gnu.org/licenses/gpl-2.0.html>.

########################################################################

MAN1=chem.n
MOSTLYCLEANADD=\
  chem \
  chem.n \
  README \
  examples/README \
  examples/122/README

RM=rm -f

all: README chem $(MAN1) $(make_examples)

README: $(srcdir)/README.txt
	sed -e "s|@g@|$(g)|g" $? >$@

.PHONY: examples
examples: examples/README examples/122/README

examples/README: $(srcdir)/examples/README.txt
	test -d examples || $(mkinstalldirs) examples;
	sed -e "s|@g@|$(g)|g" $? >$@

examples/122/README: $(srcdir)/examples/122/README.txt
	test -d examples || $(mkinstalldirs) examples;
	test -d examples/122 || $(mkinstalldirs) examples/122;
	sed -e "s|@g@|$(g)|g" $? >$@;

chem: $(srcdir)/chem.pl $(SH_DEPS_SED_SCRIPT)
	$(RM) $@;
	sed -f "$(SH_DEPS_SED_SCRIPT)" \
	    -e "s|@g@|$(g)|g" \
	    -e "s|@BINDIR@|$(DESTDIR)$(bindir)|g" \
	    -e "s|@MACRODIR@|$(DESTDIR)$(tmacdir)|g" \
	    -e "s|@PICDIR@|$(DESTDIR)$(datasubdir)/pic|g" \
	    -e "s|@VERSION@|$(version)$(revision)|g" \
	    -e "$(SH_SCRIPT_SED_CMD)" \
	    $(srcdir)/chem.pl >$@;
	chmod +x $@;

.PHONY: install_always
install_always: chem README $(srcdir)/chem.pic
	test -d $(DESTDIR)$(bindir) || $(mkinstalldirs) $(DESTDIR)$(bindir);
	$(RM) $(DESTDIR)$(bindir)/$(g)chem;
	$(INSTALL_SCRIPT) chem $(DESTDIR)$(bindir)/$(g)chem;
	test -d $(DESTDIR)$(datasubdir)/pic \
	  || $(mkinstalldirs) $(DESTDIR)$(datasubdir)/pic;
	$(RM) $(DESTDIR)$(datasubdir)/pic/chem.pic;
	$(INSTALL_DATA) $(srcdir)/chem.pic \
	  $(DESTDIR)$(datasubdir)/pic/chem.pic;

.PHONY: install_examples
install_examples:
	test -d $(DESTDIR)$(exampledir)/chem \
	  || $(mkinstalldirs) $(DESTDIR)$(exampledir)/chem;
	test -d $(DESTDIR)$(exampledir)/chem/122 \
	  || $(mkinstalldirs) $(DESTDIR)$(exampledir)/chem/122;
	find $(DESTDIR)$(exampledir)/chem -type f -exec rm -f '{}' ';'
	$(INSTALL_DATA) examples/README $(DESTDIR)$(exampledir)/chem/README;
	for i in $(srcdir)/examples/*.chem; do \
	  n=`echo $$i | sed 's|$(srcdir)/examples/||g'`; \
	  $(INSTALL_DATA) $$i $(DESTDIR)$(exampledir)/chem/$$n; \
	done;
	$(INSTALL_DATA) examples/122/README \
	  $(DESTDIR)$(exampledir)/chem/122/README;
	for i in $(srcdir)/examples/122/*.chem; do \
	  n=`echo $$i | sed 's|$(srcdir)/examples/122/||g'`; \
	  $(INSTALL_DATA) $$i $(DESTDIR)$(exampledir)/chem/122/$$n; \
	done

.PHONY: install_data

install_data: install_always $(make_install_examples)

# uninstall_sub: uninstall_always $(make_uninstall_examples)

.PHONY: uninstall_always
uninstall_always:
	$(RM) $(DESTDIR)$(bindir)/chem;
	$(RM) $(DESTDIR)$(datasubdir)/pic/chem.pic;
	-test -d $(DESTDIR)$(datasubdir)/pic && \
	  rmdir $(DESTDIR)$(datasubdir)/pic;

.PHONY: uninstall_examples
uninstall_examples:
	$(RM) $(DESTDIR)$(exampledir)/chem/122/*;
	-test -d $(DESTDIR)$(exampledir)/chem/122 && \
	  rmdir $(DESTDIR)$(exampledir)/chem/122;
	$(RM) $(DESTDIR)$(exampledir)/chem/*;
	-test -d $(DESTDIR)$(exampledir)/chem && \
	  rmdir $(DESTDIR)$(exampledir)/chem;

.PHONY: uninstall_sub
uninstall_sub: uninstall_always uninstall_examples

########################################################################
# Emacs settings
########################################################################
#
# Local Variables:
# mode: makefile
# End:
