# Makefile.sub for `groffer' (integration into the `groff' source tree)

# File position: <groff-source>/contrib/groffer/Makefile.sub

# Copyright (C) 2001-2014  Free Software Foundation, Inc.
# Written by Werner Lemberg <wl@gnu.org> and
# Bernd Warken <groff-bernd.warken-72@web.de>.

# This file is part of `groffer' which is part of `groff'.

# `groff' is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.

# `groff' is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program. If not, see
# <http://www.gnu.org/licenses/gpl-2.0.html>.

########################################################################

ROFF2MODES=dvi html pdf ps text x
ROFF2PROGS=`echo $(ROFF2MODES) | sed 's/[a-z][a-z]*/roff2&/g'`
ROFF2MAN=`echo $(ROFF2MODES) | sed 's/[a-z][a-z]*/roff2&.man/g'`
ROFF2N=`echo $(ROFF2MODES) | sed 's/[a-z][a-z]*/roff2&.n/g'`

MAN1=groffer.n \
     roff2dvi.n \
     roff2html.n \
     roff2pdf.n \
     roff2ps.n \
     roff2text.n \
     roff2x.n

MOSTLYCLEANADD=groffer $(MAN1) $(ROFF2MAN) $(ROFF2N) $(ROFF2PROGS)

RM=rm -f

all: groffer

GROFFER_PERL=subs.pl \
             main_subs.pl \
             man.pl \
             split_env.sh
GROFFER_REST=roff2.man \
             version.sh \
             groffer.man \
             groffer.pl \
             roff2.pl

groffer: $(GROFFER_PERL) $(GROFFER_REST) $(SH_DEPS_SED_SCRIPT)
	sed -f "$(SH_DEPS_SED_SCRIPT)" \
	    -e "s|@g@|$(g)|g" \
	    -e "s|@BINDIR@|$(DESTDIR)$(bindir)|g" \
	    -e "s|@libdir@|$(DESTDIR)$(libdir)|g" \
	    -e "s|@groffer_dir@|$(DESTDIR)$(groffer_dir)|g" \
	    -e "s|@VERSION@|$(version)$(revision)|g" \
	    -e "$(SH_SCRIPT_SED_CMD)" \
	     $(srcdir)/groffer.pl >$@; \
	for f in $(ROFF2PROGS); do \
	  cp $(srcdir)/roff2.pl $$f; \
	done; \
	chmod +x $@
	for m in $(ROFF2MODES); do \
	  cat $(srcdir)/roff2.man \
	    | sed 's/@ROFF2MODE@/'"$$m"'/g' > roff2$${m}.man; \
	done

install_data: groffer
	-test -d $(DESTDIR)$(bindir) || $(mkinstalldirs) $(DESTDIR)$(bindir)
	$(RM) $(DESTDIR)$(bindir)/groffer
	$(INSTALL_SCRIPT) groffer $(DESTDIR)$(bindir)/groffer
	for f in $(ROFF2PROGS); do \
	  $(RM) $(DESTDIR)$(bindir)/$$f; \
	  $(INSTALL_SCRIPT) $$f $(DESTDIR)$(bindir)/$$f; \
	done
	-test -d $(DESTDIR)$(groffer_dir) \
	  || $(mkinstalldirs) $(DESTDIR)$(groffer_dir)
	$(RM) $(DESTDIR)$(groffer_dir)/version.sh
	$(INSTALL_DATA) $(srcdir)/version.sh $(DESTDIR)$(groffer_dir)/version.sh
	for f in $(GROFFER_PERL); do \
	  $(RM) $(DESTDIR)$(groffer_dir)/$$f; \
	done
	for f in $(GROFFER_PERL); do \
	  $(INSTALL_SCRIPT) $(srcdir)/$$f $(DESTDIR)$(groffer_dir)/$$f; \
	done;

uninstall_sub:
	$(RM) $(DESTDIR)$(bindir)/groffer
	-for f in $(ROFF2PROGS); do $(RM) $(DESTDIR)$(bindir)/$$f; done
	-for f in $(GROFFER_PERL) version.sh; do \
	  $(RM) $(DESTDIR)$(groffer_dir)/$$f;\
	done
	-test -d $(DESTDIR)$(libdir)/groff/groffer && \
	  rmdir $(DESTDIR)$(libdir)/groff/groffer


########################################################################
# Emacs settings
########################################################################
#
# Local Variables:
# mode: makefile
# End:
